.. _sec-user_guide:

User guide
==========

.. toctree::
   :maxdepth: 1

   basic_concepts
   conventions
   package_structure
   onedim_experiment
   spectral_discretization
   unit_guide_user
   data/index
